@@ -27,8 +27,8 @@
 static PyObject *SetupException;
 static PyObject *OutputException;
 static PyObject *InputException;
-static PyObject *input;
-static PyObject *output;
+static PyObject *inp;
+static PyObject *out;
 static PyObject *per;
 static PyObject *high;
 static PyObject *low;
@@ -73,6 +73,11 @@ static PyObject *low;
 #define PIN38   SUNXI_GPG(10)
 #define PIN39   SUNXI_GPG(11)
 
+#define MISO    SUNXI_GPE(3)
+#define MOSI    SUNXI_GPE(2)
+#define SCK     SUNXI_GPE(1)
+#define CS      SUNXI_GPE(0)
+
 static int module_setup(void) {
     int result;
 
@@ -239,11 +244,11 @@ PyMODINIT_FUNC initA13_GPIO(void) {
     low = Py_BuildValue("i", LOW);
     PyModule_AddObject(module, "LOW", low);
 
-    input = Py_BuildValue("i", INPUT);
-    PyModule_AddObject(module, "INPUT", input);
+    inp = Py_BuildValue("i", INPUT);
+    PyModule_AddObject(module, "INP", inp);
 
-    output = Py_BuildValue("i", OUTPUT);
-    PyModule_AddObject(module, "OUTPUT", output);
+    out = Py_BuildValue("i", OUTPUT);
+    PyModule_AddObject(module, "OUT", out);
 
     per = Py_BuildValue("i", PER);
     PyModule_AddObject(module, "PER", per);
@@ -286,6 +291,21 @@ PyMODINIT_FUNC initA13_GPIO(void) {
     PyModule_AddObject(module, "PIN37", Py_BuildValue("i", PIN37));
     PyModule_AddObject(module, "PIN38", Py_BuildValue("i", PIN38));
     PyModule_AddObject(module, "PIN39", Py_BuildValue("i", PIN39));
+    PyModule_AddObject(module, "MISO", Py_BuildValue("i", MISO));
+    PyModule_AddObject(module, "MOSI", Py_BuildValue("i", MOSI));
+    PyModule_AddObject(module, "SCK", Py_BuildValue("i", SCK));
+    PyModule_AddObject(module, "CS", Py_BuildValue("i", CS));
+    
+    if(Py_AtExit(sunxi_gpio_cleanup) != 0){
+        
+        sunxi_gpio_cleanup();
+        
+#if PY_MAJOR_VERSION >= 3
+        return NULL;
+#else
+        return;
+#endif
+    }
 
 
 
